@@ -2,6 +2,7 @@ import os
 from typing import Any, Dict, Callable, Optional, Union, List, Tuple
 from inspect import isclass
 from os import path
+import re
 import json
 import yaml
 from deepmerge import always_merger
@@ -35,6 +36,7 @@ class Registry:
     CONFIG_META_PREFIX = '$'
     ARGS_KEY = '$args'
     TYPE_KEY = '$type'
+    ENV_VAR_REGEX = re.compile(r'\${(\w+):?(.+)?}')
     _default_registry: Optional['Registry'] = None
 
     @staticmethod
@@ -120,8 +122,9 @@ class Registry:
             if value.startswith('\\$'):
                 return value[1:]
 
-            if value.startswith('$$'):
-                return os.environ.get(value[2:], '')
+            if value.startswith('${'):
+                env_var, default_value = self.parse_environment_variable(value)
+                return os.environ.get(env_var, default_value)
 
             if value.startswith('$'):
                 if '.' in value:
@@ -131,6 +134,17 @@ class Registry:
 
         return value
 
+    def parse_environment_variable(self, value: str) -> Tuple[str, str]:
+        """ Parse an environment variable value like ${ENV_VAR:default} or ${ENV_VAR} """
+        match = self.ENV_VAR_REGEX.match(value)
+
+        if not match:
+            raise RegistryInvalidEnvironmentVariableError(f'Invalid environment variable syntax: {value}')
+
+        env_var, default_value = match.groups()
+
+        return env_var, default_value or ''
+
     def get_object_configuration(self, object_name: Optional[str], *args: Any, **kwargs: Any) -> Tuple[List, Dict]:
         if object_name is None or object_name not in self.configuration:
             return [], {}
@@ -249,3 +263,7 @@ class RegistryFactoryExists(RegistryError):
 
 class RegistryFactoryIsNotClassError(RegistryError):
     pass
+
+
+class RegistryInvalidEnvironmentVariableError(RegistryError):
+    pass
\ No newline at end of file
